@@ -1,4 +1,8 @@
-class DriverAPI(object):
+from splinter.element_list import ElementList
+from splinter.request_handler.request_handler import RequestHandler
+
+
+class DriverAPI(RequestHandler):
     @property
     def title(self):
         raise NotImplementedError
@@ -14,7 +18,19 @@ class DriverAPI(object):
     def visit(self, url):
         raise NotImplementedError
 
-    def switch_to_frame(self, id):
+    def back(self):
+        raise NotImplementedError
+
+    def forward(self):
+        raise NotImplementedError
+
+    def reload(self):
+        raise NotImplementedError
+
+    def get_alert(self):
+        raise NotImplementedError
+
+    def get_iframe(self, id):
         raise NotImplementedError
 
     def execute_script(self, script):
@@ -23,9 +39,11 @@ class DriverAPI(object):
     def evaluate_script(self, script):
         raise NotImplementedError
 
-    def find_by_css_selector(self, css_selector):
+    def find_by_css(self, css_selector):
         raise NotImplementedError
 
+    find_by_css_selector = find_by_css
+
     def find_by_xpath(self, xpath):
         raise NotImplementedError
 
@@ -44,16 +62,22 @@ class DriverAPI(object):
     def find_link_by_text(self, text):
         raise NotImplementedError
 
+    def find_option_by_value(self, value):
+        raise NotImplementedError
+
+    def find_option_by_text(self, text):
+        raise NotImplementedError
+
     def wait_for_element(self, selector, timeout, interval):
         raise NotImplementedError
 
-    def fill_in(self, name, value):
+    def fill(self, name, value):
         raise NotImplementedError
 
-    fill = fill_in
+    fill_in = fill
     attach_file = fill
 
-    def choose(self, name):
+    def choose(self, name, value):
         raise NotImplementedError
 
     def check(self, name):
@@ -62,9 +86,24 @@ class DriverAPI(object):
     def uncheck(self, name):
         raise NotImplementedError
 
+    def select(self, name, value):
+        raise NotImplementedError
+
+    def click_link_by_href(self, href):
+        return self.find_link_by_href(href).first.click()
+
+    def click_link_by_text(self, text):
+        return self.find_link_by_text(text).first.click()
+
+    def within(self, context):
+        return ElementList([], context, self)
+
     def quit(self):
         raise NotImplementedError
 
+    def is_element_present(self, finder, selector, wait_time=None):
+        raise NotImplementedError
+
 
 class ElementAPI(object):
 
